==> ideaIC-183.2407.10-sources.jar: com/intellij/ide/plugins/newui/PluginsGroup.java <==
// Copyright 2000-2018 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package com.intellij.ide.plugins.newui;

import com.intellij.ide.plugins.IdeaPluginDescriptor;
import com.intellij.openapi.util.text.StringUtil;
import com.intellij.ui.components.labels.LinkLabel;
import com.intellij.util.containers.ContainerUtil;
import org.jetbrains.annotations.NotNull;

import javax.swing.*;
import java.util.ArrayList;
import java.util.List;

/**
 * @author Alexander Lobas
 */
public class PluginsGroup {
  protected final String myTitlePrefix;
  public String title;
  public JLabel titleLabel;
  public LinkLabel<Object> rightAction;
  public final List<IdeaPluginDescriptor> descriptors = new ArrayList<>();
  public UIPluginGroup ui;

  public PluginsGroup(@NotNull String title) {
    myTitlePrefix = title;
    this.title = title;
  }

  public void clear() {
    ui = null;
    descriptors.clear();
    titleLabel = null;
    rightAction = null;
  }

  public void titleWithCount() {
    title = myTitlePrefix + " (" + descriptors.size() + ")";
    updateTitle();
  }

  public void titleWithEnabled(@NotNull MyPluginModel pluginModel) {
    int enabled = 0;
    for (IdeaPluginDescriptor descriptor : descriptors) {
      if (pluginModel.isEnabled(descriptor)) {
        enabled++;
      }
    }
    titleWithCount(enabled);
  }

  public void titleWithCount(int enabled) {
    title = myTitlePrefix + " (" + enabled + " of " + descriptors.size() + " enabled)";
    updateTitle();
  }

  protected void updateTitle() {
    if (titleLabel != null) {
      titleLabel.setText(title);
    }
  }

  public int addWithIndex(@NotNull IdeaPluginDescriptor descriptor) {
    descriptors.add(descriptor);
    sortByName();
    return descriptors.indexOf(descriptor);
  }

  public void sortByName() {
    sortByName(descriptors);
  }

  public static void sortByName(@NotNull List<IdeaPluginDescriptor> descriptors) {
    ContainerUtil.sort(descriptors, (o1, o2) -> StringUtil.compare(o1.getName(), o2.getName(), true));
  }
}

==> ideaIC-2018.3.3-sources.jar: com/intellij/ide/plugins/newui/PluginsGroup.java <==
// Copyright 2000-2018 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package com.intellij.ide.plugins.newui;

import com.intellij.ide.plugins.IdeaPluginDescriptor;
import com.intellij.openapi.util.text.StringUtil;
import com.intellij.ui.components.labels.LinkLabel;
import com.intellij.util.containers.ContainerUtil;
import org.jetbrains.annotations.NotNull;

import javax.swing.*;
import java.util.ArrayList;
import java.util.List;

/**
 * @author Alexander Lobas
 */
public class PluginsGroup {
  protected final String myTitlePrefix;
  public String title;
  public JLabel titleLabel;
  public LinkLabel<Object> rightAction;
  public final List<IdeaPluginDescriptor> descriptors = new ArrayList<>();
  public UIPluginGroup ui;
  public Runnable clearCallback;

  public PluginsGroup(@NotNull String title) {
    myTitlePrefix = title;
    this.title = title;
  }

  public void clear() {
    ui = null;
    descriptors.clear();
    titleLabel = null;
    rightAction = null;
    if (clearCallback != null) {
      clearCallback.run();
      clearCallback = null;
    }
  }

  public void titleWithCount() {
    title = myTitlePrefix + " (" + descriptors.size() + ")";
    updateTitle();
  }

  public void titleWithEnabled(@NotNull MyPluginModel pluginModel) {
    int enabled = 0;
    for (IdeaPluginDescriptor descriptor : descriptors) {
      if (pluginModel.isEnabled(descriptor)) {
        enabled++;
      }
    }
    titleWithCount(enabled);
  }

  public void titleWithCount(int enabled) {
    title = myTitlePrefix + " (" + enabled + " of " + descriptors.size() + " enabled)";
    updateTitle();
  }

  protected void updateTitle() {
    if (titleLabel != null) {
      titleLabel.setText(title);
    }
  }

  public int addWithIndex(@NotNull IdeaPluginDescriptor descriptor) {
    descriptors.add(descriptor);
    sortByName();
    return descriptors.indexOf(descriptor);
  }

  public void sortByName() {
    sortByName(descriptors);
  }

  public static void sortByName(@NotNull List<? extends IdeaPluginDescriptor> descriptors) {
    ContainerUtil.sort(descriptors, (o1, o2) -> StringUtil.compare(o1.getName(), o2.getName(), true));
  }
}
